@@ -65,21 +65,86 @@ StatusBar::ClearMessage() noexcept
 	doupdate();
 }
 
-#ifndef NCMPC_MINI
-
-static void
+static size_t
 format_bitrate(char *p, size_t max_length,
 	       const struct mpd_status *status) noexcept
 {
-	if (options.visible_bitrate && mpd_status_get_kbit_rate(status) > 0)
+
+#ifndef NCMPC_MINI
+	if (options.visible_bitrate && mpd_status_get_kbit_rate(status) > 0) {
 		snprintf(p, max_length,
 			 " [%d kbps]",
 			 mpd_status_get_kbit_rate(status));
-	else
+		return strlen(p);
+	} else {
+#else
+		(void)max_length;
+		(void)status;
+#endif
 		p[0] = '\0';
+		return 0;
+#ifndef NCMPC_MINI
+	}
+#endif
 }
 
-#endif /* !NCMPC_MINI */
+static void
+FormatCurrentSongTime(char *buffer, size_t size,
+		      const struct mpd_status &status,
+		      const DelayedSeek &seek) noexcept
+{
+	if (options.current_time_display == CurrentTimeDisplay::NONE)
+		return;
+
+	const unsigned total_time = mpd_status_get_total_time(&status);
+	if (total_time == 0)
+		return;
+
+	unsigned elapsed_time = seek.IsSeeking(mpd_status_get_song_id(&status))
+		? seek.GetTime()
+		: mpd_status_get_elapsed_time(&status);
+	if (elapsed_time == 0)
+		return;
+
+	char elapsed_string[32], duration_string[32];
+
+	/* checks the conf to see whether to display elapsed or
+	   remaining time */
+	switch (options.current_time_display) {
+	case CurrentTimeDisplay::NONE:
+	case CurrentTimeDisplay::ELAPSED:
+		break;
+
+	case CurrentTimeDisplay::REMAINING:
+		elapsed_time = elapsed_time < total_time
+			? total_time - elapsed_time
+			: 0;
+		break;
+	}
+
+	/* write out the time */
+	format_duration_short(elapsed_string,
+			      sizeof(elapsed_string),
+			      elapsed_time);
+	format_duration_short(duration_string,
+			      sizeof(duration_string),
+			      total_time);
+
+	snprintf(buffer, size, " [%s/%s]", elapsed_string, duration_string);
+}
+
+inline size_t
+FormatStatusRightText(char *buffer, size_t size,
+		      const struct mpd_status &status,
+		      const DelayedSeek &seek) noexcept
+{
+	/* display bitrate if visible-bitrate is true */
+	size_t offset = format_bitrate(buffer, size, &status);
+
+	FormatCurrentSongTime(buffer + offset, size - offset, status, seek);
+
+	return StringWidthMB(buffer);
+}
 
 void
 StatusBar::Update(const struct mpd_status *status,
@@ -110,50 +175,9 @@ StatusBar::Update(const struct mpd_status *status,
 		: 0;
 
 	if (state == MPD_STATE_PLAY || state == MPD_STATE_PAUSE) {
-		unsigned elapsed_time = seek.IsSeeking(mpd_status_get_song_id(status))
-			? seek.GetTime()
-			: mpd_status_get_elapsed_time(status);
-		const unsigned total_time = mpd_status_get_total_time(status);
-
-		if (elapsed_time > 0 || total_time > 0) {
-#ifdef NCMPC_MINI
-			static char bitrate[1];
-#else
-			char bitrate[16];
-#endif
-			char elapsed_string[32], duration_string[32];
-
-			/*checks the conf to see whether to display elapsed or remaining time */
-			if (options.display_remaining_time)
-				elapsed_time = elapsed_time < total_time
-					? total_time - elapsed_time
-					: 0;
-
-			/* display bitrate if visible-bitrate is true */
-#ifndef NCMPC_MINI
-			format_bitrate(bitrate, sizeof(bitrate), status);
-#endif
-
-			/* write out the time */
-			format_duration_short(elapsed_string,
-					      sizeof(elapsed_string),
-					      elapsed_time);
-			format_duration_short(duration_string,
-					      sizeof(duration_string),
-					      total_time);
-
-			snprintf(right_text, sizeof(right_text),
-				 "%s [%s/%s]",
-				 bitrate, elapsed_string, duration_string);
-		} else {
-#ifndef NCMPC_MINI
-			format_bitrate(right_text, sizeof(right_text), status);
-#else
-			right_text[0] = 0;
-#endif
-		}
-
-		right_width = StringWidthMB(right_text);
+		right_width = FormatStatusRightText(right_text,
+						    sizeof(right_text),
+						    *status, seek);
 
 #ifndef NCMPC_MINI
 		int width = COLS - left_width - right_width;
