@@ -113,13 +113,11 @@ bool
 mpdclient::HandleError()
 {
 	enum mpd_error error = mpd_connection_get_error(connection);
-
 	assert(error != MPD_ERROR_SUCCESS);
 
 	if (error == MPD_ERROR_SERVER &&
-	    mpd_connection_get_server_error(connection) == MPD_SERVER_ERROR_PERMISSION &&
-	    mpdclient_auth_callback(this))
-		return true;
+	    mpd_connection_get_server_error(connection) == MPD_SERVER_ERROR_PERMISSION)
+		return mpdclient_auth_callback(this);
 
 	mpdclient_invoke_error_callback(error,
 					mpd_connection_get_error_message(connection));
@@ -132,6 +130,21 @@ mpdclient::HandleError()
 	return false;
 }
 
+void
+mpdclient::HandleAuthError() noexcept
+{
+	enum mpd_error error = mpd_connection_get_error(connection);
+	assert(error != MPD_ERROR_SUCCESS);
+
+	mpdclient_invoke_error_callback(error,
+					mpd_connection_get_error_message(connection));
+
+	if (!mpd_connection_clear_error(connection)) {
+		Disconnect();
+		mpdclient_lost_callback();
+	}
+}
+
 #ifdef ENABLE_ASYNC_CONNECT
 #ifndef _WIN32
 
@@ -569,12 +582,9 @@ mpdclient::RunClearQueue() noexcept
 bool
 mpdclient::RunVolume(unsigned value) noexcept
 {
-	struct mpd_connection *c = GetConnection();
-	if (c == nullptr)
-		return false;
-
-	mpd_send_set_volume(c, value);
-	return FinishCommand();
+	return WithConnection([value](struct mpd_connection &c){
+		return mpd_run_set_volume(&c, value);
+	});
 }
 
 bool
@@ -598,12 +608,9 @@ mpdclient::RunVolumeDown() noexcept
 bool
 mpdclient_cmd_add_path(struct mpdclient *c, const char *path_utf8)
 {
-	struct mpd_connection *connection = c->GetConnection();
-	if (connection == nullptr)
-		return false;
-
-	return mpd_send_add(connection, path_utf8)?
-		c->FinishCommand() : false;
+	return c->WithConnection([path_utf8](struct mpd_connection &conn){
+		return mpd_run_add(&conn, path_utf8);
+	});
 }
 
 bool
@@ -807,42 +814,26 @@ mpdclient::RunMove(unsigned dest_pos, unsigned src_pos) noexcept
 bool
 mpdclient_cmd_subscribe(struct mpdclient *c, const char *channel)
 {
-	struct mpd_connection *connection = c->GetConnection();
-
-	if (connection == nullptr)
-		return false;
-
-	if (!mpd_send_subscribe(connection, channel))
-		return c->HandleError();
-
-	return c->FinishCommand();
+	return c->WithConnection([channel](struct mpd_connection &conn){
+		return mpd_run_subscribe(&conn, channel);
+	});
 }
 
 bool
 mpdclient_cmd_unsubscribe(struct mpdclient *c, const char *channel)
 {
-	struct mpd_connection *connection = c->GetConnection();
-	if (connection == nullptr)
-		return false;
-
-	if (!mpd_send_unsubscribe(connection, channel))
-		return c->HandleError();
-
-	return c->FinishCommand();
+	return c->WithConnection([channel](struct mpd_connection &conn){
+		return mpd_run_unsubscribe(&conn, channel);
+	});
 }
 
 bool
 mpdclient_cmd_send_message(struct mpdclient *c, const char *channel,
 			   const char *text)
 {
-	struct mpd_connection *connection = c->GetConnection();
-	if (connection == nullptr)
-		return false;
-
-	if (!mpd_send_send_message(connection, channel, text))
-		return c->HandleError();
-
-	return c->FinishCommand();
+	return c->WithConnection([channel, text](struct mpd_connection &conn){
+		return mpd_run_send_message(&conn, channel, text);
+	});
 }
 
 /****************************************************************************/
