@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2019 The Music Player Daemon Project
+ * (c) 2004-2020 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,9 +29,10 @@
 #include "LyricsPage.hxx"
 #include "OutputsPage.hxx"
 #include "ChatPage.hxx"
-#include "util/Macros.hxx"
 #include "config.h"
 
+#include <iterator>
+
 #include <string.h>
 
 static const PageMeta *const screens[] = {
@@ -66,7 +67,7 @@ static const PageMeta *const screens[] = {
 const PageMeta *
 GetPageMeta(unsigned i) noexcept
 {
-	return i < ARRAY_SIZE(screens)
+	return i < std::size(screens)
 		   ? screens[i]
 		   : nullptr;
 }
